@@ -4,10 +4,7 @@
 
 #include "iccomp.h"
 
-ESTRUC_ *greater (lval, rval)
-    ESTRUC_
-        *lval,
-        *rval;
+ESTRUC_ *greater (ESTRUC_ *lval, ESTRUC_ *rval)
 {
     btoi(lval);                             /* convert boolean to i */
     btoi(rval);
@@ -15,7 +12,7 @@ ESTRUC_ *greater (lval, rval)
     if (conflict(lval, rval, op_gr))        /* test type conflict */
         return(lval);
 
-    if ((lval->type & rval->type & ~ALLTYPES) == e_const)
+    if ((lval->type & rval->type & (size_t)~ALLTYPES) == e_const)
     {
         if (test_type(lval, e_int))
             lval->evalue = (lval->evalue > rval->evalue);
