@@ -36,6 +36,8 @@ ESTRUC_ *onearg(type, arg)
 
         default:
         /*
+            case f_backtick:
+            case f_getenv:
             case f_putenv:
             case f_exists:
             case f_cmd_head:
@@ -46,17 +48,14 @@ ESTRUC_ *onearg(type, arg)
             case f_g_base:
             case f_g_ext:
             case f_strlen:
+            case f_strlwr:
+            case f_strupr:
         */
             ok = test_type(arg, e_str);
     }
 
     if (ok)
-    {
-        if (type == f_strlen)
-            callhidden(he_strlen, arg);
-        else
-            callrss(arg, type);
-    }
+        callrss(arg, type);
     else
         semantic(type_conflict, funstring[type]);
 
