@@ -28,7 +28,7 @@ void fun_fgets()
     size_t offset = intValue(top() - 1);
     FILE *inf;
 
-    reg = listConstructor();
+    reg = *listConstructor();
 
     if 
     ( 
@@ -44,10 +44,8 @@ void fun_fgets()
             char buffer[20];     
             sprintf (buffer, "%d", (int)ftell(inf));
 
-            listAdd_cP(&reg, dest);
+            listAdd_swallow_cP(&reg, dest);
             listAdd_cP(&reg, buffer);
-
-            free(dest);
         }
         fclose (inf);
     }
