@@ -3,5 +3,5 @@
 void listAdd_cP(LISTVAR_ *list, char const *txt)
 {
     incsize(list);
-    addtxt(list, txt);
+    addtxt(list, xstrdup(txt));
 }
