@@ -10,10 +10,10 @@
     structure of the binary file:
 
         version                             e.g., "1.00", without ascii-z
-        offset of the string constant-area  (long)
-        offset of the variable area         (long)
-        offset of the filenames area        (long) (end of BIN_HEADER_)
-        offset of first instr. to execute   (long)
+        offset of the string constant-area  (INT32)
+        offset of the variable area         (INT32)
+        offset of the filenames area        (INT32) (end of BIN_HEADER_)
+        offset of first instr. to execute   (INT32)
 
         code                                (first byte is first instruction)
         ascii-z string constant area
@@ -202,6 +202,7 @@
 
 #include "../icm.h"
 #include <stdio.h>
+#include <unistd.h>
 
 /*
                     The compiler uses E_TYPE 0 to indicate
@@ -223,7 +224,7 @@ typedef enum
     e_code          = (1 << 7),             /* code */
 
     e_pre_inc_dec   = (1 << 8),             /* pre-inc or pre-dec        */
-    e_post_inc_dec  = (1 << 9),             /* post-inc or post-dec      */
+    e_post_inc_dec  = (1 << 9)              /* post-inc or post-dec      */
 } E_TYPE_;
 
 typedef enum                                /* names of rss-functions */
@@ -270,10 +271,15 @@ typedef enum                                /* names of rss-functions */
 
                       /* reserved rss function opcodes for subreleases */
     f_strlen,                               /* NEW: only for the compiler */
-    f_substr,                               /* IDEM */
+    f_strfind,                              /* IDEM */
     f_getpid,                               /* used by several programs  */
 
-    f_hlt = f_system + 10,                  /* dummy marker for non-existing */
+    f_substr,
+    f_getenv,
+
+    f_backtick,                             /* 4 left until f_hlt */
+
+    f_hlt = f_system + 10                   /* dummy marker for non-existing */
 } FUNNR_;
 
 typedef enum
@@ -372,7 +378,6 @@ typedef struct                              /* defined variable */
         vu;                                 /* value of the element */
 } VAR_;
 
-#ifndef MSDOS
 struct _find_t                               /* abbreviated variant */
 {
     char
@@ -380,7 +385,6 @@ struct _find_t                               /* abbreviated variant */
     unsigned
         attrib;                             /* returned attribute */
 };
-#endif
 
 typedef struct
 {
@@ -391,7 +395,7 @@ typedef struct
 } ICMAKE_FIND_;
 
 
-BIN_HEADER_ *readheader (FILE *, unsigned);
+BIN_HEADER_ *readheader (FILE *, size_t);
 
 extern ICMAKE_FIND_
     ifs;                                    /* in: ./rss/findnext.c */
@@ -400,40 +404,28 @@ extern char
     version[],
     release[];
 
-/*
-            replacement functions for non-dos systems
-*/
-
-#ifndef MSDOS
 
 void        _makepath(char *, const char *, const char *,
                       const char *, const char *);
 void        _splitpath(const char *, char *, char *, char *, char *);
-unsigned    _dos_findfirst(char const *, unsigned, struct _find_t *);
-unsigned    _dos_findnext(struct _find_t *);
+size_t    _dos_findfirst(char const *, size_t, struct _find_t *);
+size_t    _dos_findnext(struct _find_t *);
 
 int         _spawnlp(int, const char *, const char *, ...);           /* ok */
 int         _spawnvp(int, const char *, const char **);               /* ok */
 char        *_strlwr(char *);                                         /* ok */
-
-#define     _heapmin()
-
-#else
-
-unsigned    redirect_end(unsigned, unsigned);
-
-#endif  /*  MSDOS   */
+char        *_strupr(char *);
 
 char const *change_ext (char const *, char const *);
 char const *change_base (char const *, char const *);
 char const *change_path (char const *, char const *);
 
 int      chesc(char *, int *);
-void     copyright(char *, char *, char *, int);/* copyright message */
-char     *filefound();                          /* test attrib/pattern  */
-char     *findfirst(char const *, unsigned);    /* first entry matching pattern */
-char     *findnext();                           /* remaining matching entries   */
-char     *fgetz (char *, unsigned, FILE *);
+void     copyright(char *, char *, char *);     /* copyright message */
+char     *filefound(void);                      /* test attrib/pattern  */
+char     *findfirst(char const *, size_t);    /* first entry matching pattern */
+char     *findnext(void);                       /* remaining matching entries   */
+char     *fgetz (char *, size_t, FILE *);
 
 char const *get_ext(char const *);
 char const *get_base(char const *);
@@ -447,18 +439,22 @@ char     *ic_getoptval(int *, char **);
 #define  getopt      ic_getopt
 #define  getoptval   ic_getoptval
 
-char     *getstring (FILE *, INT32, UNS16);
-char     *hexstring (UNS16, UNS16);
+char     *getstring (FILE *, INT32, size_t);
+
+char     *hexstring (size_t, size_t);
+
 char     *program_name(char *);                 /* make programname from argv[0] */
-unsigned redirect_start(unsigned, unsigned);    /* ASM function for DOS */
+
 char     *stresc(char *);
-char     *xstrdup (char const *);
+
+char     *try_source(char const *);         /* return allocated source[.im] */
+char     *xstrdup(char const *);
 char     *xstrcat (char *, char const *);
 
 void     error (char *, ...);
 void     spawn_err (char *);
 
-void     *xrealloc (void *, int);
+void     *xrealloc (void *, size_t);
 
 int      exists  (char const *);
 int      older   (char const *, char const *);
@@ -468,8 +464,8 @@ INT16    getint16 (FILE *);
 
 OPCODE_  getopcode (FILE *);
 
-UNS16    getvar (FILE *, BIN_HEADER_ *, VAR_ **);
+UNS16    getvar(FILE *, BIN_HEADER_ *, VAR_ **);
 
-VAR_     initvar (VAR_);
+void     initvar(VAR_ *);
 
 #endif
