@@ -16,8 +16,6 @@
 
 */
 
-#ifndef MSDOS
-
 #include <stdio.h>
 #include <string.h>
 #include "../icm.h"
@@ -37,8 +35,7 @@ void _makepath(char * path,
 
         if (dir[strlen(dir) - 1] != DIRSEP)
         {
-            unsigned short
-                l;
+            size_t l;
 
             path[l = strlen(path)] = DIRSEP;
             path[++l] = '\x0';              /*  make it an asciiz   */
@@ -56,4 +53,3 @@ void _makepath(char * path,
         strcat(path, ext);
     }
 }
-#endif  /*  MSDOS  */
